@@ -2,19 +2,21 @@ import click
 from flask.cli import with_appcontext
 from ..generator import g_api, g_api_crud
 
+
 @click.group("api")
 def group():
     """
     API generator.
     """
 
+
 @group.command()
 @with_appcontext
 @click.argument("name")
-@click.option("--crud", is_flag=True, help="Membuat crud berdasarkan ORM model.")
+@click.option("--crud", is_flag=True, help="Create a REST API based on the ORM model.")
 def new(name, crud):
     """
-    Create api ler.
+    Create REST API.
     """
 
     func = g_api
@@ -22,4 +24,5 @@ def new(name, crud):
         func = g_api_crud
     func(name)
 
+
 command = group
