@@ -1,6 +1,8 @@
 import click
+from flask.cli import with_appcontext
 from ..generator import g_command
 
+
 @click.group("command")
 def group():
     """
@@ -9,6 +11,7 @@ def group():
 
 
 @group.command()
+@with_appcontext
 @click.argument("name")
 def new(name):
     """
@@ -17,4 +20,5 @@ def new(name):
 
     g_command(name)
 
+
 command = group
